#include "managepresets.h"
#include "ui_managepresets.h"

managepresets::managepresets(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::managepresets)
{
    ui->setupUi(this);
    readpresets();
}

managepresets::~managepresets()
{
    delete ui;
}

void managepresets::readpresets()
{
    QDir presetsdir("/opt/theme-customizer/presets");
    QStringList presets = presetsdir.entryList(QDir::Files | QDir::NoDotAndDotDot, QDir::DirsFirst);
    ui->presetslist->addItems(presets);
}

void managepresets::on_presetslist_currentIndexChanged(int index)
{

        if (ui->presetslist->currentIndex() > 2) {
        ui->delbutton->setEnabled(true);
        } else {
        ui->delbutton->setDisabled(true);
        }

        if (!ui->presetslist->currentIndex() == 0) {
            ui->loadbutton->setEnabled(true);
        }

}
